==> nextcloud-24.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/ca.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Cercles",
    "Circles' files" : "Fitxers del cercle",
    "Select circles to filter by" : "Seleccioneu els cercles per filtrar",
    "No circles found" : "No s'han trobat cercles",
    "Please select circles to filter by" : "Si us plau, seleccioneu els cercles per filtrar",
    "No files found for the selected circles" : "No s'ha trobat cap fitxer amb els cercles seleccionats",
    "You created the circle {circle}" : "Heu creat el cercle {circle}",
    "{author} created the circle {circle}" : "{author} ha creat el cercle {circle}",
    "You deleted {circle}" : "Heu suprimit {circle}",
    "{author} deleted {circle}" : "{author} ha suprimit {circle}",
    "You linked {group} to {circle}" : "Heu enllaçat {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} s'ha enllaçat a {circle} per {author}",
    "You unlinked {group} from {circle}" : "Heu desenllaçat {group} de {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} s'ha desenllaçat de {circle} per {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Heu canviat el nivell del grup {group} enllaçat a {circle} a%1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ha canviat el nivell del grup {group} enllaçat en {circle} a%1$s",
    "You sent a request to link {circle} with {remote}" : "Heu enviat una sol·licitud per enllaçar {circle} amb {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} ha enviat una sol·licitud per enllaçar {circle} amb {remote}",
    "{remote} requested a link with {circle}" : "{remote} ha sol·licitat un enllaç amb {circle}",
    "The request to link {circle} with {remote} has been rejected" : "S'ha rebutjat la sol·licitud d'enllaç {circle} amb {remote}",
    "The request to link {remote} with {circle} has been canceled remotely" : "La sol·licitud d'enllaçar {remote} amb {circle} s'ha cancel·lat de manera remota",
    "The request to link {circle} with {remote} has been accepted" : "S'ha acceptat la sol·licitud d'enllaç {circle} amb {remote}",
    "You dismissed the request to link {remote} with {circle}" : "Heu rebutjat la sol·licitud per enllaçar {remote} amb {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} ha rebutjat la sol·licitud d'enllaç {remote} amb {circle}",
    "You canceled the request to link {circle} with {remote}" : "Heu cancel·lat la sol·licitud per enllaçar {circle} amb {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} ha cancel·lat la sol·licitud per enllaçar {circle} amb {remote}",
    "You accepted the request to link {remote} with {circle}" : "Heu acceptat la sol·licitud d'enllaç {remote} amb {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} ha acceptat la sol·licitud d'enllaç {remote} amb {circle}",
    "A link between {circle} and {remote} is now up and running" : "Ara hi ha un enllaç entre {circle} i {remote}",
    "The link between {circle} and {remote} has been shutdown remotely" : "L'enllaç entre {circle} i {remote} s'ha tancat de manera remota",
    "You closed the link between {circle} and {remote}" : "Heu tancat l'enllaç entre {circle} i {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} ha tancat l'enllaç entre {circle} i {remote}",
    "You joined {circle}" : "Us heu unit a {circle}",
    "{member} joined {circle}" : "{member} s'ha unit a {circle}",
    "You accepted the invitation to join {circle}" : "Heu acceptat la invitació per unir-vos a {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} ha acceptat la invitació per unir-se a {circle}",
    "You added {member} as member to {circle}" : "Heu afegit {member} com a membre de {circle}",
    "You have been added as member to {circle} by {author}" : "Heu afegit com a membre a {circle} per {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} s'ha afegit com a membre a {circle} per {author}",
    "You added {external} to {circle}" : "Heu afegit {extern} a {cercle}",
    "{external} has been added to {circle} by {author}" : "S'ha afegit {external} a {circle} per {author}",
    "You accepted {member}'s request to join {circle}" : "Heu acceptat la sol·licitud de {member} per unir-vos a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "La vostra sol·licitud d'unir-vos a {circle} ha estat acceptada per {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La sol·licitud d'{member} per unir-se a {circle} ha estat acceptada per {author}",
    "You left {circle}" : "Heu deixat {circle}",
    "{member} left {circle}" : "{member} ha deixat {circle}",
    "You declined the invitation to join {circle}" : "Heu rebutjat la invitació per unir-vos a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha rebutjat una invitació per unir-se a {circle}",
    "You cancelled your request to join {circle}" : "Heu cancel·lat la vostra sol·licitud per unir-vos a {circle}",
    "{member} cancelled his request to join {circle}" : "{member} ha cancel·lat la seva sol·licitud per unir-se a {circle}",
    "You removed {member} from {circle}" : "Heu suprimit {member} de {circle}",
    "You have been removed from {circle} by {author}" : "Heu suprimit {circle} per {author}",
    "{member} has been removed from {circle} by {author}" : "{member} s'ha suprimit de {circle} per {author}",
    "You removed {external} from {circle}" : "Heu suprimit {extern} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} s'ha suprimit de {circle} per {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Heu cancel·lat la invitació de {member} per unir-vos a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "La vostra invitació per unir-vos a {circle} ha estat cancel·lada per {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha cancel·lat la invitació {member} per unir-se a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Heu rebutjat la sol·licitud de {member} per unir-vos a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "La vostra sol·licitud d'unir-vos a {circle} ha estat rebutjada per {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La sol·licitud d'{member} per unir-se a {circle} ha estat rebutjada per {author}",
    "You invited {member} to join {circle}" : "Heu convidat {member} a unir-se a {circle}",
    "You have been invited to join {circle} by {author}" : "Heu estat convidats a unir-vos a {circle} per {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} ha estat convidat a unir-se {circle} per {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Heu canviat el nivell de {member} al cercle {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha canviat el vostre nivell a {circle} a%1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha canviat el nivell {member} a {circle} a%1$s",
    "You sent a request to join {circle}" : "Heu enviat una sol·licitud per unir-vos a {circle}",
    "{member} sent a request to join {circle}" : "{member} ha enviat una sol·licitud per unir-se a {circle}",
    "You are the new owner of {circle}" : "Sou el nou propietari de {circle}",
    "{member} is the new owner of {circle}" : "{member} és el nou propietari de {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Sobre els esdeveniments que ocorren a un <strong>Cercle</strong> del qual vostè és membre",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Qualsevol esdeveniment important d'un <strong>Cercle</strong> que esteu moderant",
    "On global events happening in any <strong>Circle</strong>" : "Sobre els esdeveniments globals que ocorren en qualsevol <strong>Cercle</strong>",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Obre",
    "Hidden" : "Ocult",
    "Local" : "Local",
    "Root" : "Arrel",
    "Federated" : "Federat",
    "Contact" : "Contacte",
    "Circle" : "Cercle",
    "Member" : "Membre",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Propietari",
    "%s shared »%s« with you." : "%s compartit »%s« amb vós.",
    "%s on %s" : "%son %s",
    "Password to access »%1$s« shared to you by %2$s" : "Contrasenya d'accés »%1$s« compartida per %2$s",
    "Password to access »%s«" : "Contrasenya per accedir »%s«",
    "It is protected with the following password:" : "Està protegit amb la contrasenya següent:",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "Click the button below to open it." : "Feu clic al botó de sota per obrir-lo.",
    "Open »%s«" : "Obre »%s«",
    "Password to access files shared to you by %1$s" : "Contrasenya per accedir als fitxers que us comparteix %1$s",
    "Password to access files" : "Contrasenya per accedir als fitxers",
    "%s shared multiple files with you." : "%s us ha compartit diversos fitxers.",
    "Circle not found" : "No s'ha trobat el cercle",
    "Circle not found " : "No s'ha trobat el cercle ",
    "A circle with that name exists" : "Un cercle amb aquest nom ja existeix",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "No podeu utilitzar l'Aplicació de cercles fins que l'administrador hagi permès com a mínim un tipus de cercles",
    "This member does not exist" : "Aquest membre no existeix",
    "This user is already a member of the circle" : "Aquest usuari ja és membre del cercle",
    "Federated link not found" : "No s'ha trobat l'enllaç federat",
    "This feature is not available for personal circles" : "Aquesta funció no està disponible per als cercles personals",
    "The circle is not federated" : "El cercle no és federat",
    "You cannot join this circle" : "No podeu unir-vos a aquest cercle",
    "This member is not a moderator" : "Aquest membre no és moderador",
    "Insufficient privileges" : "Privilegis insuficients",
    "This member is the owner of the circle" : "Aquest membre és el propietari del cercle",
    "Level cannot be changed for this type of member" : "El nivell no pot ser canviat per aquest tipus de membre",
    "You are already a member of this circle" : "Ja sou membre d'aquest cercle",
    "You have been blocked from this circle" : "Heu estat blocats d'aquest cercle",
    "The user is already a member of this circle" : "L'usuari ja és membre d'aquest cercle",
    "The user has already been invited into this circle" : "L'usuari ja ha estat convidat a aquest cercle",
    "You are now a member of the Circle \"%2$s\"" : "Ara sou membre del Cercle \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Vostè ha estat convidat per %1$s en el Cercle \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s ha enviat una sol·licitud per ser membre del Cercle \"%2$s\"",
    "Accept" : "Accepta",
    "Refuse" : "Rebutja",
    "Leave the circle" : "Deixa el cercle",
    "%s" : "%s",
    "Personal Circle" : "Cercle personal",
    "You need a specify a type of circle" : "Heu d'especificar un tipus de cercle",
    "This member is not the owner of the circle" : "Aquest membre no és el propietari del cercle",
    "This member is not an admin of the circle" : "Aquest membre no és un administrador d'aquest cercle",
    "Group contains too many members" : "El grup conté massa membres",
    "This group does not exist" : "Aquest grup no existeix",
    "This group is already linked to the circle" : "Aquest grup ja està enllaçat al cercle",
    "You cannot edit level in a personal circle" : "No podeu editar el nivell en un cercle personal",
    "Group cannot be set as owner of a circle" : "El grup no es pot posar com a propietari del cercle",
    "now" : "ara",
    "This user does not exist" : "Aquest usuari no existeix",
    "Email format is not valid" : "El format de correu no és vàlid",
    "This contact is not available" : "Aquest contacte no està disponible",
    "Could not find share" : "No es pot trobar el compartit",
    "Bring cloud-users closer together." : "Apropeu els usuaris del núvol.",
    "No files in here" : "Aquí no hi ha fitxers",
    "No entries found in this folder" : "No hi ha cap entrada dins d'aquesta carpeta",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Modificat"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/ca.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Cercles",
    "Circles' files" : "Fitxers del cercle",
    "Select circles to filter by" : "Seleccioneu els cercles per filtrar",
    "No circles found" : "No s'han trobat cercles",
    "Please select circles to filter by" : "Si us plau, seleccioneu els cercles per filtrar",
    "No files found for the selected circles" : "No s'ha trobat cap fitxer amb els cercles seleccionats",
    "You created the circle {circle}" : "Heu creat el cercle {circle}",
    "{author} created the circle {circle}" : "{author} ha creat el cercle {circle}",
    "You deleted {circle}" : "Heu suprimit {circle}",
    "{author} deleted {circle}" : "{author} ha suprimit {circle}",
    "You linked {group} to {circle}" : "Heu enllaçat {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} s'ha enllaçat a {circle} per {author}",
    "You unlinked {group} from {circle}" : "Heu desenllaçat {group} de {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} s'ha desenllaçat de {circle} per {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Heu canviat el nivell del grup {group} enllaçat a {circle} a%1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ha canviat el nivell del grup {group} enllaçat en {circle} a%1$s",
    "You sent a request to link {circle} with {remote}" : "Heu enviat una sol·licitud per enllaçar {circle} amb {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} ha enviat una sol·licitud per enllaçar {circle} amb {remote}",
    "{remote} requested a link with {circle}" : "{remote} ha sol·licitat un enllaç amb {circle}",
    "The request to link {circle} with {remote} has been rejected" : "S'ha rebutjat la sol·licitud d'enllaç {circle} amb {remote}",
    "The request to link {remote} with {circle} has been canceled remotely" : "La sol·licitud d'enllaçar {remote} amb {circle} s'ha cancel·lat de manera remota",
    "The request to link {circle} with {remote} has been accepted" : "S'ha acceptat la sol·licitud d'enllaç {circle} amb {remote}",
    "You dismissed the request to link {remote} with {circle}" : "Heu rebutjat la sol·licitud per enllaçar {remote} amb {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} ha rebutjat la sol·licitud d'enllaç {remote} amb {circle}",
    "You canceled the request to link {circle} with {remote}" : "Heu cancel·lat la sol·licitud per enllaçar {circle} amb {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} ha cancel·lat la sol·licitud per enllaçar {circle} amb {remote}",
    "You accepted the request to link {remote} with {circle}" : "Heu acceptat la sol·licitud d'enllaç {remote} amb {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} ha acceptat la sol·licitud d'enllaç {remote} amb {circle}",
    "A link between {circle} and {remote} is now up and running" : "Ara hi ha un enllaç entre {circle} i {remote}",
    "The link between {circle} and {remote} has been shutdown remotely" : "L'enllaç entre {circle} i {remote} s'ha tancat de manera remota",
    "You closed the link between {circle} and {remote}" : "Heu tancat l'enllaç entre {circle} i {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} ha tancat l'enllaç entre {circle} i {remote}",
    "You joined {circle}" : "Us heu unit a {circle}",
    "{member} joined {circle}" : "{member} s'ha unit a {circle}",
    "You accepted the invitation to join {circle}" : "Heu acceptat la invitació per unir-vos a {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} ha acceptat la invitació per unir-se a {circle}",
    "You added {member} as member to {circle}" : "Heu afegit {member} com a membre de {circle}",
    "You have been added as member to {circle} by {author}" : "Heu afegit com a membre a {circle} per {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} s'ha afegit com a membre a {circle} per {author}",
    "You added {external} to {circle}" : "Heu afegit {extern} a {cercle}",
    "{external} has been added to {circle} by {author}" : "S'ha afegit {external} a {circle} per {author}",
    "You accepted {member}'s request to join {circle}" : "Heu acceptat la sol·licitud de {member} per unir-vos a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "La vostra sol·licitud d'unir-vos a {circle} ha estat acceptada per {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La sol·licitud d'{member} per unir-se a {circle} ha estat acceptada per {author}",
    "You left {circle}" : "Heu deixat {circle}",
    "{member} left {circle}" : "{member} ha deixat {circle}",
    "You declined the invitation to join {circle}" : "Heu rebutjat la invitació per unir-vos a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha rebutjat una invitació per unir-se a {circle}",
    "You cancelled your request to join {circle}" : "Heu cancel·lat la vostra sol·licitud per unir-vos a {circle}",
    "{member} cancelled his request to join {circle}" : "{member} ha cancel·lat la seva sol·licitud per unir-se a {circle}",
    "You removed {member} from {circle}" : "Heu suprimit {member} de {circle}",
    "You have been removed from {circle} by {author}" : "Heu suprimit {circle} per {author}",
    "{member} has been removed from {circle} by {author}" : "{member} s'ha suprimit de {circle} per {author}",
    "You removed {external} from {circle}" : "Heu suprimit {extern} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} s'ha suprimit de {circle} per {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Heu cancel·lat la invitació de {member} per unir-vos a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "La vostra invitació per unir-vos a {circle} ha estat cancel·lada per {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha cancel·lat la invitació {member} per unir-se a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Heu rebutjat la sol·licitud de {member} per unir-vos a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "La vostra sol·licitud d'unir-vos a {circle} ha estat rebutjada per {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La sol·licitud d'{member} per unir-se a {circle} ha estat rebutjada per {author}",
    "You invited {member} to join {circle}" : "Heu convidat {member} a unir-se a {circle}",
    "You have been invited to join {circle} by {author}" : "Heu estat convidats a unir-vos a {circle} per {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} ha estat convidat a unir-se {circle} per {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Heu canviat el nivell de {member} al cercle {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha canviat el vostre nivell a {circle} a%1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha canviat el nivell {member} a {circle} a%1$s",
    "You sent a request to join {circle}" : "Heu enviat una sol·licitud per unir-vos a {circle}",
    "{member} sent a request to join {circle}" : "{member} ha enviat una sol·licitud per unir-se a {circle}",
    "You are the new owner of {circle}" : "Sou el nou propietari de {circle}",
    "{member} is the new owner of {circle}" : "{member} és el nou propietari de {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Sobre els esdeveniments que ocorren a un <strong>Cercle</strong> del qual vostè és membre",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Qualsevol esdeveniment important d'un <strong>Cercle</strong> que esteu moderant",
    "On global events happening in any <strong>Circle</strong>" : "Sobre els esdeveniments globals que ocorren en qualsevol <strong>Cercle</strong>",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Obre",
    "Hidden" : "Ocult",
    "Local" : "Local",
    "Root" : "Arrel",
    "Federated" : "Federat",
    "Contact" : "Contacte",
    "Circle" : "Cercle",
    "Member" : "Membre",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Propietari",
    "%s shared »%s« with you." : "%s compartit »%s« amb vós.",
    "%s on %s" : "%son %s",
    "Password to access »%1$s« shared to you by %2$s" : "Contrasenya d'accés »%1$s« compartida per %2$s",
    "Password to access »%s«" : "Contrasenya per accedir »%s«",
    "It is protected with the following password:" : "Està protegit amb la contrasenya següent:",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "Click the button below to open it." : "Feu clic al botó de sota per obrir-lo.",
    "Open »%s«" : "Obre »%s«",
    "Password to access files shared to you by %1$s" : "Contrasenya per accedir als fitxers que us comparteix %1$s",
    "Password to access files" : "Contrasenya per accedir als fitxers",
    "%s shared multiple files with you." : "%s us ha compartit diversos fitxers.",
    "Circle not found" : "No s'ha trobat el cercle",
    "Circle not found " : "No s'ha trobat el cercle ",
    "A circle with that name exists" : "Un cercle amb aquest nom ja existeix",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "No podeu utilitzar l'Aplicació de cercles fins que l'administrador hagi permès com a mínim un tipus de cercles",
    "This member does not exist" : "Aquest membre no existeix",
    "Federated link not found" : "No s'ha trobat l'enllaç federat",
    "This feature is not available for personal circles" : "Aquesta funció no està disponible per als cercles personals",
    "The circle is not federated" : "El cercle no és federat",
    "You cannot join this circle" : "No podeu unir-vos a aquest cercle",
    "This member is not a moderator" : "Aquest membre no és moderador",
    "Insufficient privileges" : "Privilegis insuficients",
    "This member is the owner of the circle" : "Aquest membre és el propietari del cercle",
    "Level cannot be changed for this type of member" : "El nivell no pot ser canviat per aquest tipus de membre",
    "You are already a member of this circle" : "Ja sou membre d'aquest cercle",
    "You have been blocked from this circle" : "Heu estat blocats d'aquest cercle",
    "You are now a member of the Circle \"%2$s\"" : "Ara sou membre del Cercle \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Vostè ha estat convidat per %1$s en el Cercle \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s ha enviat una sol·licitud per ser membre del Cercle \"%2$s\"",
    "Accept" : "Accepta",
    "Refuse" : "Rebutja",
    "Leave the circle" : "Deixa el cercle",
    "%s" : "%s",
    "Personal Circle" : "Cercle personal",
    "You need a specify a type of circle" : "Heu d'especificar un tipus de cercle",
    "This member is not the owner of the circle" : "Aquest membre no és el propietari del cercle",
    "This member is not an admin of the circle" : "Aquest membre no és un administrador d'aquest cercle",
    "Group contains too many members" : "El grup conté massa membres",
    "This group does not exist" : "Aquest grup no existeix",
    "This group is already linked to the circle" : "Aquest grup ja està enllaçat al cercle",
    "You cannot edit level in a personal circle" : "No podeu editar el nivell en un cercle personal",
    "Group cannot be set as owner of a circle" : "El grup no es pot posar com a propietari del cercle",
    "now" : "ara",
    "Email format is not valid" : "El format de correu no és vàlid",
    "This contact is not available" : "Aquest contacte no està disponible",
    "Could not find share" : "No es pot trobar el compartit",
    "Bring cloud-users closer together." : "Apropeu els usuaris del núvol.",
    "No files in here" : "Aquí no hi ha fitxers",
    "No entries found in this folder" : "No hi ha cap entrada dins d'aquesta carpeta",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Modificat",
    "This user is already a member of the circle" : "Aquest usuari ja és membre del cercle",
    "The user is already a member of this circle" : "L'usuari ja és membre d'aquest cercle",
    "The user has already been invited into this circle" : "L'usuari ja ha estat convidat a aquest cercle",
    "This user does not exist" : "Aquest usuari no existeix"
},
"nplurals=2; plural=(n != 1);");
